==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/pt_BR.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Painel",
    "Dashboard app" : "aplicativo Painel",
    "Show something" : "Mostrar alguma coisa",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar widgets",
    "Get more widgets from the app store" : "Obtenha mais widgets a partir da loja de aplicativos",
    "Change background image" : "Mudar imagem de fundo",
    "Weather service" : "Serviço de Clima",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Para sua privacidade, as informações de Tempo são solicitadas pelo servidor Nextcloud de forma que o serviço de Tempo não receba suas informações pessoais.",
    "Weather data from Met.no" : "dados de Tempo do Met.no",
    "geocoding with Nominatim" : "geocodificado com Nominatim",
    "elevation data from OpenTopoData" : "dados topográficos de OpenTopoData",
    "Weather" : "Clima",
    "Status" : "Status",
    "Good evening, {name}" : "Boa noite, {name}",
    "Good evening" : "Boa noite",
    "Good afternoon, {name}" : "Boa tarde, {name}",
    "Good afternoon" : "Boa tarde",
    "Good morning, {name}" : "Bom dia, {name}",
    "Good morning" : "Bom dia",
    "Good night, {name}" : "Boa noite, {name}",
    "Good night" : "Boa noite",
    "Pick from files" : "Escolher de Arquivos",
    "Default images" : "Imagens padrão",
    "Plain background" : "Fundo simples",
    "Insert from {productName}" : "Inserir de {productName}"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/pt_BR.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Painel",
    "Dashboard app" : "aplicativo Painel",
    "Show something" : "Mostrar alguma coisa",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar widgets",
    "Get more widgets from the app store" : "Obtenha mais widgets a partir da loja de aplicativos",
    "Change background image" : "Mudar imagem de fundo",
    "Weather service" : "Serviço de Clima",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Para sua privacidade, as informações de Tempo são solicitadas pelo servidor Nextcloud de forma que o serviço de Tempo não receba suas informações pessoais.",
    "Weather data from Met.no" : "dados de Tempo do Met.no",
    "geocoding with Nominatim" : "geocodificado com Nominatim",
    "elevation data from OpenTopoData" : "dados topográficos de OpenTopoData",
    "Weather" : "Clima",
    "Status" : "Status",
    "Good morning" : "Bom dia",
    "Good morning, {name}" : "Bom dia, {name}",
    "Good afternoon" : "Boa tarde",
    "Good afternoon, {name}" : "Boa tarde, {name}",
    "Good evening" : "Boa noite",
    "Good evening, {name}" : "Boa noite, {name}",
    "Default images" : "Imagens padrão",
    "Plain background" : "Fundo simples",
    "Insert from {productName}" : "Inserir de {productName}",
    "Good night, {name}" : "Boa noite, {name}",
    "Good night" : "Boa noite",
    "Pick from files" : "Escolher de Arquivos"
},
"nplurals=2; plural=(n > 1);");
